use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006008
use Test::Spelling 0.12;
use Pod::Wordlist;

set_spell_cmd('aspell list');
add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
LICENCE
MERCHANTABILITY
Alan
Young
ayoung
harleypig
Harley
Pig
Сергей
Романов
sromanov
lib
Dist
Zilla
Plugin
Test
Legal
